@@ -187,5 +187,8 @@ WakeUp_SongIsActive=False
 UseAlternativeAlarm=False
 AlternativeAlarm=""
 
+cliStart=""
+cliStop=""
+
 CurrentVolume=0
 WakeUp_Song_Volume_Increase_Step=4 #increase step time in pro mille (0.1%)
