@@ -66,16 +66,32 @@ def SetAlarm():
             action_run.command = data.AlternativeAlarm
 
         try:
-            print event
+            print "Event details:"
+#            print event
             print event.appid
 #            print event.message
-            print event.alarm_time
-
+            print Seconds2Tuple(event.alarm_time)
         except:
             print "Could not print event data"
 
-        data.AlarmID = alarm.add_event(event)
-        print "AlarmID:", data.AlarmID
+        #python-alarm seems to be buggy.
+        #Sometimes it raises randomly the error InvalidEventException
+        #We try to readd it if this happens
+        for i in range(0, 5):
+            print "Try to add alarm event (", i, ")"
+            try:
+                data.AlarmID = alarm.add_event(event) #Try to add alarm event
+                print "AlarmID:", data.AlarmID
+                break #alarm is set, leave loop
+            except:
+                print "Could not add alarm event"
+                if(i<4): #give it another try
+                    pass
+                else:
+                    print i+1, "trials without success, raise the error about alarm.add_event(event)"
+                    raise #ok, now really raise the error
+
+        print "Ok, could set the alarm"
 
         event = alarm.get_event(data.AlarmID) #read out again to check if set correctly
 
@@ -121,6 +137,29 @@ def delete_all_preexisting_Alarms():
 
 
 
+###########################################################################
+## Function:    print_list_of_all_alarms
+## Description: This function searchs for any SleepAnalyser alarms in the
+##                MAEMO alarm queue and shows them
+##                This function is mainly used for debugging
+## Parameters:  none
+## Returns:     none
+###########################################################################
+def print_list_of_all_alarms():
+    print "* Print list of all SleepAnalyser alarms"
+    if(data.DeviceIsN900==True): #We are on a N900
+        event = alarm.query_event(0, 0, 0, 0, "") #get list of all set alarm in N900
+        i=0
+        for e in event:
+            e2=alarm.get_event(e)
+            if(e2.appid=="SleepAnalyser"): #filter our alarms
+                print "Found alarm:", time.ctime(e2.trigger), e2.appid , e2.title, e2.message #print our alarms
+                i=i+1
+        if(i==0): print "* No old alarms found"
+        else: print "* Found", i, "of our alarms"
+
+
+
 ###########################################################################
 ## Function:    DeleteAlarm
 ## Description: This function delets a specific alarm from the AMEMO alarm queue
@@ -134,7 +173,7 @@ def DeleteAlarm():
                 event = alarm.get_event(data.AlarmID) #get data of to be deleted alarm
                 alarm.delete_event(data.AlarmID)
 
-                print "* Delete old Alarm:", time.ctime(event.trigger)
+                print "* Delete old alarm:", time.ctime(event.trigger)
             except:
                 pass
         else:
@@ -142,9 +181,9 @@ def DeleteAlarm():
 
         data.AlarmID=-1
 
-        if(data.AlarmIsActive==False): #if alarm never came, remove from record
-            records.AlarmTime_seconds=-1
-            records.AlarmTime_tuple=-1
+#        if(data.AlarmIsActive==False): #if alarm never came, remove from record
+#            records.AlarmTime_seconds=-1
+#            records.AlarmTime_tuple=-1
     else:
         if(data.debug==True): print "* No alarm to be deleted"
 
