@@ -36,6 +36,7 @@ _ = i18n.language.ugettext
 
 
 
+
 ###########################################################################
 ## Function:    LoadConfig
 ## Description: This function loads the data from the config file
@@ -253,6 +254,16 @@ def LoadConfig():
     except:
         config.set('main', 'UseAlternativeAlarm', str(data.UseAlternativeAlarm))
 
+    try:
+        data.cliStart = config.get('main', 'cliStart')
+    except:
+        config.set('main', 'cliStart', "")
+
+    try:
+        data.cliStop = config.get('main', 'cliStop')
+    except:
+        config.set('main', 'clisStop', "")
+
 
 
     try:
@@ -422,6 +433,12 @@ def SwitchModes(start):
                         set_silent(True)
                     data.PreviousVolume=GetVolume()
 
+                    if(data.cliStart!=""):
+                        cmd=data.cliStart+" &" #Expert option to run a script at recording start
+                        print "### Run command: ", cmd
+                        b = os.popen(cmd)
+                        b.close()
+
             else: #end of recording
                 if(data.SwitchedModes==True): #protection so it only gets switched once
                     data.SwitchedModes=False
@@ -431,6 +448,11 @@ def SwitchModes(start):
                         set_silent(False)
                     SetVolume(data.PreviousVolume)
 
+                    if(data.cliStop!=""):
+                        cmd=data.cliStop+" &" #Expert option to run a script at recording stop
+                        print "### Run command: ", cmd
+                        b = os.popen(cmd)
+                        b.close()
 
 
 
